PlatformProxyHttpOverrides class

Inheritance

Constructors

PlatformProxyHttpOverrides(PlatformProxy platformProxy)

Properties

hashCode → int
The hash code for this object.
no setterinherited
platformProxy → PlatformProxy
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createHttpClient(SecurityContext? context) → HttpClient
Returns a new HttpClient using the given context.
inherited
findProxyFromEnvironment(Uri url, Map<String, String>? environment) → String
Resolves the proxy server to be used for HTTP connections.
inherited
findProxyFromEnvironmentAsync(Uri url, Map<String, String> environment) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited