Proxy class

Constructors

Proxy({required String host, required String port, required String type, required String user, required String password})
Proxy.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
host → String
final
pacString → String
no setter
pacStringWithCredentials → String
no setter
password → String
final
port → String
final
priority → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
user → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override